<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>Mån</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>Tis</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>Ons</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>Fre</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>Lör</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>Sön</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation>Molnigt</translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation>Mestadels molnigt</translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation>Delvis molnigt</translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation>Lätt regn</translation>
    </message>
    <message>
        <source>Showers</source>
        <translation>Skurar</translation>
    </message>
    <message>
        <source>Rain</source>
        <translation>Regn</translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation>FM skurar</translation>
    </message>
    <message>
        <source>Fog</source>
        <translation>Dimma</translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation>Några skurar</translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation>Mestadels soligt</translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation>Soligt</translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation>Spridda snöflingor</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation>FM moln/EM sol</translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation>Lite åska</translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation>Spridda åskväder</translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation>EM skurar</translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation>EM skurar/blåst</translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation>Regn/snöbyar</translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation>Några snöbyar</translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation>Molnigt/blåsigt</translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation>Lätt snö/blåst</translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation>Mestadels molnigt/blåsigt</translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation>Regn/åska</translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation>Delvis molnigt/blåsigt</translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation>FM Regn/Snöbyar</translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation>Lätt regn/blåst</translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation>Skurar/blåsigt</translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation>Mestadels soligt/blåsigt</translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation>Lätt snöfall</translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation>Regn/blåst</translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation>Spridd lätt snö/blåst</translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation>Spridda kraftiga stormar</translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation>EM Åska</translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation>Åska</translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation>Soligt/blåsigt</translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation>FM Åska</translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation>FM regn</translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation>Lite åska/blåst</translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation>Regn/snö</translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation>Spridda åskväder/blåst</translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation>FM Skurar/blåst</translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation>Spridda snöbyar</translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation>Snö till Is/blåst</translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation>Snö till regn</translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation>FM lätt regn</translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation>EM lätt regn</translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation>EM regn</translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation>Snöbyar</translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation>Regn till snö</translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation>EM regn/snö</translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation>Några skurar/blåsigt</translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation>Snö/blåst</translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation>EM regn/snöbyar</translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation>EM regn/snö/blåst</translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation>Regn/snöbyar/blåst</translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation>Regn/snö/blåst</translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation>Lätt snöfall</translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation>EM snö</translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation>Några snöbyar/blåst</translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation>Lätt snö/blåst</translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation>Snöblandat regn</translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation>FM Snöblandat regn</translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation>Kraftigt regn/Underkylt regn</translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation>FM lätt snö</translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation>Regn/Underkylt regn</translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation>Åska/blåst</translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation>Regnstänk</translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation>FM Snöbyar</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation>FM moln/EM sol/blåst</translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation>FM regn/snö/blåst</translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation>Regn till snö/blåst</translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation>Snö till Snöblandat regn</translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation>EM Snöbyar/blåst</translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation>Snö och is till regn</translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation>Kraftigt regn</translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation>FM Regn/Is</translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation>FM Snöbyar/blåst</translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation>FM lätt snö/blåst</translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation>EM lätt regn/blåst</translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation>FM Lätt snöblandat regn</translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation>FM Lätt snö/blåst</translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation>Kraftigt regn/blåst</translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation>EM Snöbyar</translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation>Snö till Regn/blåst</translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation>EM Lätt regn/Is</translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation>FM snö</translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation>Snö till Is</translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation>Snöblandat regn/blåst</translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation>EM lätt snö</translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation>FM duggregn</translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation>Kraftiga stormar/blåst</translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation>EM duggregn</translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation>Duggregn</translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation>FM lätt regn/blåst</translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation>FM regn/blåst</translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation>Snöblandat regn till snö</translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation>Snöbyar/blåsigt</translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation>Lätta regnskurar</translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation>Lätt regn med åska</translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation>Lätt duggregn</translation>
    </message>
    <message>
        <source>Mist</source>
        <translation>Dimma</translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation>Rök</translation>
    </message>
    <message>
        <source>Haze</source>
        <translation>Lätt dimma</translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation>Lätta snöbyar</translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation>Lätta snöbyar/Blåsigt</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Klart</translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation>Lätt molnighet</translation>
    </message>
    <message>
        <source>Fair</source>
        <translation>Uppehåll</translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation>Norr</translation>
    </message>
    <message>
        <source>NNE</source>
        <translation>Nord nordost</translation>
    </message>
    <message>
        <source>NE</source>
        <translation>Nordost</translation>
    </message>
    <message>
        <source>E</source>
        <translation>Öst</translation>
    </message>
    <message>
        <source>SE</source>
        <translation>Sydost</translation>
    </message>
    <message>
        <source>SSE</source>
        <translation>Syd sydost</translation>
    </message>
    <message>
        <source>S</source>
        <translation>Söder</translation>
    </message>
    <message>
        <source>SSW</source>
        <translation>Syd Sydväst</translation>
    </message>
    <message>
        <source>SW</source>
        <translation>Sydväst</translation>
    </message>
    <message>
        <source>W</source>
        <translation>Väst</translation>
    </message>
    <message>
        <source>NW</source>
        <translation>Nordväst</translation>
    </message>
    <message>
        <source>NNW</source>
        <translation>Nord nordväst</translation>
    </message>
    <message>
        <source>ENE</source>
        <translation>Ost nordost</translation>
    </message>
    <message>
        <source>ESE</source>
        <translation>Ost sydost</translation>
    </message>
    <message>
        <source>WSW</source>
        <translation>Väst sydväst</translation>
    </message>
    <message>
        <source>WNW</source>
        <translation>Väst nordväst</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>Laddar...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ hämtar väderdata ... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>Nuvarande förhållanden</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Luftfuktighet</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Lufttryck</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Vind</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Sikt</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Vindkyleffekt</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>UV Strålning</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>De kommande dagarna</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>Min</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>Max</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>Dagens prognos</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>Morgondagens prognos</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>Prognos för</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>Dopplerradar</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Karta ej tillgänglig</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>REGN</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>MIX/IS</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>SNÖ</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>LÄTT</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>KRAFTIGT</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>Mata in postnummer</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>Inställningar för Vädervisaren</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>För att spara, tryck &apos;i&apos;. För att avbryta tryck ESCAPE</translation>
    </message>
    <message>
        <source>COLD</source>
        <translation>KALL</translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation>KALLAST</translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation>MOLNTEMPERATUR</translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation>är ogiltig)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation> Ingen plats satt, läs README-filen</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation> - PAUSAD -</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>Konfigurerar Vädervisaren...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>Använd höger piltangent för att välja enhet...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>Väderenheter</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Plats</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>Agressivitet</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation>Imperiella (Fahrenheit, tum etc)</translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation>Metriska (Celsius, kPa etc)</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>Konfiguration sparad...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>Hämtar väderdata...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>Använd höger piltangent för att välja plats...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>Använd höger piltangent för att välja agressivitetsnivå...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation>1 Höghastighetsförbindelse</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation>8 Medelsnabb förbindelse</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation>15 Låg förbindelsehastighet</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>Hämtar väderdata...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>Uppdaterar väderdata...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>Lugn</translation>
    </message>
    <message>
        <source> at </source>
        <translation> i </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Obegränsad</translation>
    </message>
    <message>
        <source> F</source>
        <translation>F</translation>
    </message>
    <message>
        <source> C</source>
        <translation>C</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation>(minimal)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation>(måttlig)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation>(hög)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation>(extrem)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>Idag är högsta temperatur </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation> och lägsta temperatur </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation> grader. För närvarande är luftfuktigheten </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>% och vindhastigheten </translation>
    </message>
    <message>
        <source> calm.</source>
        <translation>lugn.</translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation>är </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation>mph från </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation>Km/h från </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation> Sikten kommer att vara obegränsad idag.</translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation> Ingen prognos för sikten.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation> Sikten kommer att vara </translation>
    </message>
    <message>
        <source> miles.</source>
        <translation>miles.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation>km.</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Söndag</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tisdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Lördag</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>Datumfel</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>Imorgon förväntas högsta temperatur vara </translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>Prognos: </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>Väderdata från: </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Uppdaterar...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation>(All information ej tillgänglig)</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation>*** Ogiltigt plats-ID eller serverfel ***</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>dopplerradar</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation>satellitbild</translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to try again without animated radar maps.</source>
        <translation>Myth kunde inte hämta dina väderdata inom utsatt tid (%1 sekunder).
Tryck OK för att försöka igen med längre tid. Tryck Avbryt för att försöka igen utan animerade radarkartor.</translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to abort.</source>
        <translation>Myth kunde inte hämta dina väderdata inom utsatt tid (%1 sekunder).
Tryck OK för att försöka igen med längre tid. Tryck Avbryt för att avbryta.</translation>
    </message>
</context>
</TS>
